tiled.client.array.DaskArrayClient
==================================

.. currentmodule:: tiled.client.array

.. autoclass:: DaskArrayClient

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DaskArrayClient.__init__
      ~DaskArrayClient.download
      ~DaskArrayClient.export
      ~DaskArrayClient.login
      ~DaskArrayClient.logout
      ~DaskArrayClient.new_variation
      ~DaskArrayClient.read
      ~DaskArrayClient.read_block
      ~DaskArrayClient.refresh
      ~DaskArrayClient.structure
      ~DaskArrayClient.update_metadata
      ~DaskArrayClient.write
      ~DaskArrayClient.write_block
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~DaskArrayClient.chunks
      ~DaskArrayClient.context
      ~DaskArrayClient.dims
      ~DaskArrayClient.dtype
      ~DaskArrayClient.formats
      ~DaskArrayClient.item
      ~DaskArrayClient.metadata
      ~DaskArrayClient.metadata_revisions
      ~DaskArrayClient.nbytes
      ~DaskArrayClient.ndim
      ~DaskArrayClient.offline
      ~DaskArrayClient.references
      ~DaskArrayClient.shape
      ~DaskArrayClient.size
      ~DaskArrayClient.specs
      ~DaskArrayClient.uri
   
   